//Chamada das bibliotecas
#include "DWIN_COMM.h"
#include <HX711_ADC.h> //Instalar o bliblioteca no gerenciador do software
#include "PID_v1.h"

//Definição dos pinos do controlador OPS012
//Saidas digiais
#define pin_Y1 13
#define pin_Y2 12
#define pin_Y3 27
#define pin_Y4 26
#define pin_Y5 25
#define pin_Y6 33

//Entradas digitais
#define pin_X1 15
#define pin_X2 14
#define pin_X3 39
#define pin_X4 36

//Entradas analógicas
#define AV3 35
#define AV4 34

//Saidas analogicas
#define AO1 32
#define AO2 23

//Entradas de temperatura
const int Temp_DOUT_PIN1 = 18;
const int Temp_SCK_PIN1 = 5;

//variaveis para o teste das saidas analogicas
const int ledChannel1 = 0;
int dutyCycle1 = 0;

//Variaveis para temperatura
long INP_Raw_temp = 0;
long INP_Calib_temp = 0;
#define amostras 5
long leituras[amostras];
long soma = 0;
double INP_Act_temp = 0;

//Variaveis para PID
double OUT_PID_Output = 0;
double PAR_PID_Setpoint = 0;
double PAR_Kp = 1, PAR_Ki = 1, PAR_Kd = 0;
int VAR_AUX_Control = 0;
int VAR_Control = 0;
unsigned long TMR_Time_PID = 0;

//Variaveis IHM
int16_t IHM_BTN_Luz = 0;
int16_t IHM_BTN_Liga_Temperatura = 0;
int16_t IHM_PAR_Set_Temperatura = 0;
int16_t IHM_STA_Act_Temperatura = 0;
int16_t IHM_BTN_Liga_Tempo = 0;
int16_t IHM_PAR_Set_Tempo = 0;
int16_t IHM_STA_Act_Tempo = 0;

//Variaveis para Timer
unsigned long VAR_StartTime = 0;
unsigned long TMR_Buzzer = 0;
unsigned long TMR_Current_Time = 0;

int OUT_Buzzer =0;
int OUT_Luz = 0;
int OUT_Resistencia = 0;

//chamada da biblioteca
HX711_ADC Sensor1(Temp_DOUT_PIN1, Temp_SCK_PIN1);
DWIN Comm3(115200, &Serial1, true, 99); // TTL
PID pid(&INP_Act_temp, &OUT_PID_Output, &PAR_PID_Setpoint, PAR_Kp, PAR_Ki, PAR_Kd, DIRECT);

#include  "IHM_Ctrl.h"
#include  "IO_Ctrl.h"
#include  "Luz_Ctrl.h"
#include  "PID_Ctrl.h"
#include  "Timer_Ctrl.h"

void setup() {
  Serial.begin(115200);//USB
  Serial1.begin(115200, SERIAL_8N1, 22, 21); // (TTL)
  Serial2.begin(115200); //(485)

  //definições função PWM para as sídas analógicas
  ledcSetup(ledChannel1, 1000, 10);
  ledcAttachPin(AO1, ledChannel1);
  
  //Inicializa hardware
  pinMode(pin_X1, INPUT);
  pinMode(pin_X2, INPUT);
  pinMode(pin_X3, INPUT);
  //A leitura do X4 é feita como analógica

  pinMode(pin_Y1, OUTPUT);
  pinMode(pin_Y2, OUTPUT);
  pinMode(pin_Y3, OUTPUT);
  pinMode(pin_Y4, OUTPUT);
  pinMode(pin_Y5, OUTPUT);
  pinMode(pin_Y6, OUTPUT);

  //incio da biblioteca HX711
  Sensor1.begin();
  Sensor1.start(2000, false);
  Sensor1.setCalFactor(1);

  //incio da biblioteca pid
  pid.SetOutputLimits(0, 932);
  pid.SetSampleTime(10);
  pid.SetTunings(PAR_Kp, PAR_Ki, PAR_Kd);

  delay(3000);

  Comm3.setPage(1);//Muda para a tela principal = 1

}

void loop() {
  IHM_Ctrl();
  IO_Ctrl();
  Luz_Ctrl();
  PID_Ctrl();
  Timer_Ctrl();
}
